@@ -13,11 +13,14 @@ if [[ "${!KOLLA_BOOTSTRAP[*]}" ]]; then
     exit 0
 fi
 
+GENERATOR_ARGS="--output-file /etc/nginx/nginx.conf"
 if [[ -n "${LISTEN_ADDRESS}" ]]; then
-    skyline-nginx-generator -o /etc/nginx/nginx.conf --listen-address "${LISTEN_ADDRESS}"
-else
-    skyline-nginx-generator -o /etc/nginx/nginx.conf
+    GENERATOR_ARGS+=" --listen-address ${LISTEN_ADDRESS}"
 fi
+if [[ -n "${SSL_CERTFILE}" ]] && [[ -n "${SSL_KEYFILE}" ]]; then
+    GENERATOR_ARGS+=" --ssl-certfile ${SSL_CERTFILE} --ssl-keyfile ${SSL_KEYFILE}"
+fi
+skyline-nginx-generator ${GENERATOR_ARGS}
 
 nginx
 
