@@ -34,6 +34,13 @@ log_dir = Opt(
     default="./log",
 )
 
+log_file = Opt(
+    name="log_file",
+    description="Log file",
+    schema=StrictStr,
+    default="skyline.log",
+)
+
 secret_key = Opt(
     name="secret_key",
     description="Secret key",
@@ -106,21 +113,30 @@ prometheus_basic_auth_password = Opt(
 
 ssl_enabled = Opt(
     name="ssl_enabled",
-    description="enable ssl",
+    description="Enable ssl",
     schema=StrictBool,
     default=True,
 )
 
+cafile = Opt(
+    name="cafile",
+    description="A path to a CA file",
+    schema=StrictStr,
+    default="",
+)
+
 GROUP_NAME = __name__.split(".")[-1]
 ALL_OPTS = (
     debug,
     log_dir,
+    log_file,
     secret_key,
     access_token_expire,
     access_token_renew,
     cors_allow_origins,
     session_name,
     ssl_enabled,
+    cafile,
     database_url,
     prometheus_endpoint,
     prometheus_enable_basic_auth,
